#!/bin/sh -e

./bootstrap
./configure "$@"
